# swagger-java-client

## Requirements

Building the API client library requires [Maven](https://maven.apache.org/) to be installed.

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn deploy
```

Refer to the [official documentation](https://maven.apache.org/plugins/maven-deploy-plugin/usage.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
    <groupId>io.swagger</groupId>
    <artifactId>swagger-java-client</artifactId>
    <version>1.0.0</version>
    <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "io.swagger:swagger-java-client:1.0.0"
```

### Others

At first generate the JAR by executing:

    mvn package

Then manually install the following JARs:

* target/swagger-java-client-1.0.0.jar
* target/lib/*.jar

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

import io.swagger.client.*;
import io.swagger.client.auth.*;
import io.swagger.client.model.*;
import io.swagger.client.api.DefaultApi;

import java.io.File;
import java.util.*;

public class DefaultApiExample {

    public static void main(String[] args) {
        
        DefaultApi apiInstance = new DefaultApi();
        String token_ = "token__example"; // String | Ключ доступа, полученный при авторизации
        try {
            BigDecimal result = apiInstance.balanceGet(token_);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling DefaultApi#balanceGet");
            e.printStackTrace();
        }
    }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://www.1gb.ru/api*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**balanceGet**](docs/DefaultApi.md#balanceGet) | **GET** /balance | Аккаунт: баланс
*DefaultApi* | [**balanceLicGet**](docs/DefaultApi.md#balanceLicGet) | **GET** /balance.lic | Аккаунт: баланс аккаунта лицензий
*DefaultApi* | [**billingDebtGet**](docs/DefaultApi.md#billingDebtGet) | **GET** /billing/debt | Информация по дебету аккаунта
*DefaultApi* | [**billingInfoGet**](docs/DefaultApi.md#billingInfoGet) | **GET** /billing/info | Информация об аккаунте
*DefaultApi* | [**billingLimitsGet**](docs/DefaultApi.md#billingLimitsGet) | **GET** /billing/limits | Получить ограничения аккаунта
*DefaultApi* | [**dnsProlongListGet**](docs/DefaultApi.md#dnsProlongListGet) | **GET** /dns/prolong/list | Информация по продлению доменов
*DefaultApi* | [**emailAddGet**](docs/DefaultApi.md#emailAddGet) | **GET** /email/add | Создание почтового ящика
*DefaultApi* | [**emailAliasDeleteGet**](docs/DefaultApi.md#emailAliasDeleteGet) | **GET** /email/alias/delete | Удаление псевдонимов почтовых ящиков
*DefaultApi* | [**emailAliasListGet**](docs/DefaultApi.md#emailAliasListGet) | **GET** /email/alias/list | Получить список псевдонимов почтовых ящиков
*DefaultApi* | [**emailDeleteGet**](docs/DefaultApi.md#emailDeleteGet) | **GET** /email/delete | Удаление почтового ящика
*DefaultApi* | [**emailListGet**](docs/DefaultApi.md#emailListGet) | **GET** /email/list | Получить список почтовых ящиков
*DefaultApi* | [**updatesLastGet**](docs/DefaultApi.md#updatesLastGet) | **GET** /updates/last | Идентификатор последнего уведомления в аудите
*DefaultApi* | [**updatesListGet**](docs/DefaultApi.md#updatesListGet) | **GET** /updates/list | Список записей аудита
*DefaultApi* | [**websiteDeleteGet**](docs/DefaultApi.md#websiteDeleteGet) | **GET** /website/delete | Удаление сайта
*DefaultApi* | [**websiteListGet**](docs/DefaultApi.md#websiteListGet) | **GET** /website/list | Список сайтов аккаунта
*AuthAPIApi* | [**authLoginPost**](docs/AuthAPIApi.md#authLoginPost) | **POST** /auth/login | Получить ключ доступа
*AuthAPIApi* | [**authStartGet**](docs/AuthAPIApi.md#authStartGet) | **GET** /auth/start | Получить соль
*DNSApi* | [**dnsAddGet**](docs/DNSApi.md#dnsAddGet) | **GET** /dns/add | Создание записи домена
*DNSApi* | [**dnsBindGet**](docs/DNSApi.md#dnsBindGet) | **GET** /dns/bind | Привязка одного домена к другому
*DNSApi* | [**dnsListGet**](docs/DNSApi.md#dnsListGet) | **GET** /dns/list | Получить список доменных имён
*DNSApi* | [**dnsProlongListGet**](docs/DNSApi.md#dnsProlongListGet) | **GET** /dns/prolong/list | Информация по продлению доменов
*DNSApi* | [**dnsRawGet**](docs/DNSApi.md#dnsRawGet) | **GET** /dns/raw | Редактирование \&quot;сырой\&quot; зоны
*DNSApi* | [**dnsRawManagedmxGet**](docs/DNSApi.md#dnsRawManagedmxGet) | **GET** /dns/raw/managedmx | Редактировать DNS-зону
*HostingftpAPIApi* | [**ftpListGet**](docs/HostingftpAPIApi.md#ftpListGet) | **GET** /ftp/list | Получить список зарегистрированных аккаунтов FTP
*HostingiisAPIApi* | [**iisListGet**](docs/HostingiisAPIApi.md#iisListGet) | **GET** /iis/list | Список сайтов IIS
*MicrosoftSQLServerApi* | [**mssqlListGet**](docs/MicrosoftSQLServerApi.md#mssqlListGet) | **GET** /mssql/list | Получить список аккаунтов в MSSQL
*MySQLPostgresApi* | [**databaseListGet**](docs/MySQLPostgresApi.md#databaseListGet) | **GET** /database/list | Список аккаунтов в базах данных UNIX
*VDSHyperVOpenVZApi* | [**vdsCreateGet**](docs/VDSHyperVOpenVZApi.md#vdsCreateGet) | **GET** /vds/create | Изменение параметров VDS
*VDSHyperVOpenVZApi* | [**vdsDeleteGet**](docs/VDSHyperVOpenVZApi.md#vdsDeleteGet) | **GET** /vds/delete | Удаление VDS
*VDSHyperVOpenVZApi* | [**vdsIpAddGet**](docs/VDSHyperVOpenVZApi.md#vdsIpAddGet) | **GET** /vds/ip/add | Добавление IP на VDS
*VDSHyperVOpenVZApi* | [**vdsIpDeleteGet**](docs/VDSHyperVOpenVZApi.md#vdsIpDeleteGet) | **GET** /vds/ip/delete | Удаление IP с VDS
*VDSHyperVOpenVZApi* | [**vdsIpListGet**](docs/VDSHyperVOpenVZApi.md#vdsIpListGet) | **GET** /vds/ip/list | Список IP-адресов виртуальных серверов
*VDSHyperVOpenVZApi* | [**vdsListGet**](docs/VDSHyperVOpenVZApi.md#vdsListGet) | **GET** /vds/list | Список виртуальных серверов
*VDSHyperVOpenVZApi* | [**vdsRebootGet**](docs/VDSHyperVOpenVZApi.md#vdsRebootGet) | **GET** /vds/reboot | Перезагрузка VDS
*VDSHyperVOpenVZApi* | [**vdsTemplatesListGet**](docs/VDSHyperVOpenVZApi.md#vdsTemplatesListGet) | **GET** /vds/templates-list | Список шаблонов виртуальных серверов
*VDSHyperVOpenVZApi* | [**vdsUpdateGet**](docs/VDSHyperVOpenVZApi.md#vdsUpdateGet) | **GET** /vds/update | Создание VDS


## Documentation for Models

 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse2001](docs/InlineResponse2001.md)
 - [InlineResponse20010](docs/InlineResponse20010.md)
 - [InlineResponse20011](docs/InlineResponse20011.md)
 - [InlineResponse20012](docs/InlineResponse20012.md)
 - [InlineResponse20013](docs/InlineResponse20013.md)
 - [InlineResponse20014](docs/InlineResponse20014.md)
 - [InlineResponse2002](docs/InlineResponse2002.md)
 - [InlineResponse2003](docs/InlineResponse2003.md)
 - [InlineResponse2004](docs/InlineResponse2004.md)
 - [InlineResponse2005](docs/InlineResponse2005.md)
 - [InlineResponse2006](docs/InlineResponse2006.md)
 - [InlineResponse2007](docs/InlineResponse2007.md)
 - [InlineResponse2008](docs/InlineResponse2008.md)
 - [InlineResponse2009](docs/InlineResponse2009.md)
 - [_](docs/_.md)


## Documentation for Authorization

All endpoints do not require authorization.
Authentication schemes defined for the API:

## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issue.

## Author



